==> kdebindings-2.2.2.tar.bz2: kdebindings-2.2.2/kdejava/koala/org/kde/koala/KCompletionBoxSignals.java <==
package org.kde.koala;
import org.kde.qt.*;


/** {@link KCompletionBox} emits these signals */
public interface KCompletionBoxSignals {
	void rightButtonPressed( QListBoxItem arg1, QPoint arg2 );

/** 
 Emitted whenever the user chooses to ignore the available
 selections and close the this box.
     
*/
	void userCancelled( String arg1 );
	void selected( QListBoxItem arg1 );
	void destroyed();
	void returnPressed( QListBoxItem arg1 );
	void rightButtonClicked( QListBoxItem arg1, QPoint arg2 );
	void contentsMoving( int x, int y );

/** 
 Emitted when an item was selected, contains the text of
 the selected item.
     
*/
	void activated( String arg1 );
	void pressed( QListBoxItem arg1, QPoint arg2 );
	void highlighted( QListBoxItem arg1 );
	void clicked( QListBoxItem arg1, QPoint arg2 );
	void currentChanged( QListBoxItem arg1 );
	void mouseButtonPressed( int arg1, QListBoxItem arg2, QPoint arg3 );
	void mouseButtonClicked( int arg1, QListBoxItem arg2, QPoint arg3 );

/** 
 This signal gets emitted whenever the user double clicks into the 
 listbox. 

 Note that you may not delete any {@link QListBoxItem} objects in slots
 connected to this signal.  

 This signal is more or less here for the sake of completeness.
 You should normally not need to use this. In most cases its better 
 to use {@link KCompletionBox#executed} instead.
   
*/
	void doubleClicked( QListBoxItem item, QPoint pos );
	void selectionChanged( QListBoxItem arg1 );
	void onViewport();
	void onItem( QListBoxItem item );

/** 
 Emitted whenever the user executes an listbox item. 

 That means depending on the KDE wide Single Click/Double Click 
 setting the user clicked or double clicked on that item.

 Note that you may not delete any {@link QListBoxItem} objects in slots 
 connected to this signal.
   
*/
	void executed( QListBoxItem item, QPoint pos );
}

==> kdebindings-3.0.1.tar.bz2: kdebindings-3.0.1/kdejava/koala/org/kde/koala/KCompletionBoxSignals.java <==
package org.kde.koala;
import org.kde.qt.*;


/** {@link KCompletionBox} emits these signals */
public interface KCompletionBoxSignals {
	void rightButtonPressed( QListBoxItem arg1, QPoint arg2 );

/** 
 Emitted whenever the user chooses to ignore the available
 selections and close the this box.
     
*/
	void userCancelled( String arg1 );
	void selected( QListBoxItem arg1 );
	void destroyed( QObject obj );
	void returnPressed( QListBoxItem arg1 );
	void rightButtonClicked( QListBoxItem arg1, QPoint arg2 );
	void contentsMoving( int x, int y );

/** 
 Emitted when an item was selected, contains the text of
 the selected item.
     
*/
	void activated( String arg1 );
	void pressed( QListBoxItem arg1, QPoint arg2 );
	void highlighted( QListBoxItem arg1 );
	void clicked( QListBoxItem arg1, QPoint arg2 );
	void contextMenuRequested( QListBoxItem arg1, QPoint arg2 );
	void currentChanged( QListBoxItem arg1 );
	void mouseButtonPressed( int arg1, QListBoxItem arg2, QPoint arg3 );
	void mouseButtonClicked( int arg1, QListBoxItem arg2, QPoint arg3 );

/** 
 This signal gets emitted whenever the user double clicks into the 
 listbox. 

 Note that you may not delete any {@link QListBoxItem} objects in slots
 connected to this signal.  

 This signal is more or less here for the sake of completeness.
 You should normally not need to use this. In most cases its better 
 to use {@link KCompletionBox#executed} instead.
   
*/
	void doubleClicked( QListBoxItem item, QPoint pos );
	void selectionChanged( QListBoxItem arg1 );
	void onViewport();
	void onItem( QListBoxItem item );

/** 
 Emitted whenever the user executes an listbox item. 

 That means depending on the KDE wide Single Click/Double Click 
 setting the user clicked or double clicked on that item.

 Note that you may not delete any {@link QListBoxItem} objects in slots 
 connected to this signal.
   
*/
	void executed( QListBoxItem item, QPoint pos );
}
